pub fn noyafmt_command() -> CommandExpand description
Build the clap::Command for noyafmt.
Used by the build script and cargo xtask to drive
clap_complete and clap_mangen against the same Command tree
the binary uses at runtime.
pub fn noyafmt_command() -> CommandBuild the clap::Command for noyafmt.
Used by the build script and cargo xtask to drive
clap_complete and clap_mangen against the same Command tree
the binary uses at runtime.