pub fn noyavalidate_command() -> CommandExpand description
Build the clap::Command for noyavalidate.
Used by the build script and cargo xtask to drive
clap_complete and clap_mangen against the same Command tree
the binary uses at runtime.
pub fn noyavalidate_command() -> CommandBuild the clap::Command for noyavalidate.
Used by the build script and cargo xtask to drive
clap_complete and clap_mangen against the same Command tree
the binary uses at runtime.